@@ -8,9 +8,9 @@ from .scripts import DepsReader
 
 
 def run():
-	script, = sys.argv[1:]
-	deps = DepsReader.load(script).read()
-	print(' '.join(deps.params()))
+    (script,) = sys.argv[1:]
+    deps = DepsReader.load(script).read()
+    print(' '.join(deps.params()))
 
 
 __name__ == '__main__' and run()
